package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````E14``#0````0D0```````#0`(``,
M`"@`&``7``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!<````7````!`````$````!````````````````````G`\`
M`)P/```$`````!````$`````$````!`````0``!-*0``32D```4`````$```
M`0````!`````0````$```*A+``"H2P``!``````0```!````_(T``/R=``#\
MG0``*`(``'02```&`````!````(````,C@``#)X```R>``#0````T`````8`
M```$````!````,P!``#,`0``S`$``"@````H````!`````0```!3Y71DS`$`
M`,P!``#,`0``*````"@````$````!````%#E=&1H?@``:'X``&A^``#T````
M]`````0````$````4>5T9```````````````````````````!@```!````!2
MY71D_(T``/R=``#\G0``!`(```0"```$`````0```"]L:6(O;&0M;75S;"UI
M,S@V+G-O+C$```0````8````!0```$=.50`!``'`!`````$````"``'`!```
M```````1````1P````@````(`````!`0`"5`!(`H`!`$H(8`A(`!```+(`0)
M.(`208H$"`@`````1P```$L```!/````4````%8```!7````6`````````!:
M````6P````````!<````70```%\``````````````&I_FGSJT^\.SMY'+6_%
MWQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!N^.2
M?%7#/-)GK\QFB`=PTT-%U>PS8MOM%8PES'^IG)O@IP(*:QJ>4*/@^TD`````
M`````````````````0``````````````$@````D``````````````!$```#'
M`0`````````````1````8P$`````````````$@```!```````````````!(`
M``"@`0`````````````2````&```````````````$@```!\`````````````
M`!(```#4`0`````````````2````K`$`````````````$@```/H"````````
M`````"$````H```````````````2````+@``````````````$@```#4`````
M`````````!(```#'`@`````````````2````N`(`````````````$@```!$"
M`````````````!(````\```````````````2````EP(`````````````$@``
M`$,``````````````!(```!+```````````````2````@`(`````````````
M$@```%,``````````````!(```!<```````````````@````L0(`````````
M````$@```'@``````````````!(```!]```````````````2````Y0$`````
M````````$0```)X"`````````````!(````^`@`````````````2````A```
M````````````$@```(L``````````````"`````P`@`````````````2````
M30,`````````````$@```/D"`````````````!$```!B`@`````````````2
M````Y@(`````````````$@```/`!`````````````!(```#[`@``````````
M```1````J0``````````````$@```-X"`````````````!(```!Q`0``````
M```````2````L@``````````````(@```,$``````````````!(```"I`@``
M```````````2````3@(`````````````$@```,8``````````````!(```#,
M```````````````@````BP(`````````````$@```.8``````````````!(`
M``"1`0`````````````2````ZP``````````````(`````<!````````````
M`!(```!P`@`````````````2````#0$`````````````$@```(`!````````
M`````!(````;`0`````````````2````+`$`````````````$@````P"````
M`````````!(````=`@`````````````2````,@$`````````````$@```%<"
M`````````````!(```#7`@`````````````2````00$`````````````$@``
M`,\"`````````````!(````'`@`````````````2````50$`````````````
M$@````,#`````````````!(```#X`@`````````````A````7`$`````````
M````$@```/,"``#`$P``U0$``!(`"P#!`0``03D```$````2``P`CP,``&TB
M``"\!0``$@`+`#L$```S*@``7@```!(`"P!L`P``C!T```4````2``L`^0,`
M```0```!````$@`(`+(#```I*```"@(``!(`"P`?!```D1T``*4!```2``L`
MZ@,``"2@````````$``5`'T#``#)(0``I````!(`"P"<`P``(AP``#L````2
M``L`I`,``%$A``!-````$@`+`,@#``"_-@``_````!(`"P#=`P``-A\``!4`
M```2``L`-@0``'"P````````$``5`#(#``"P%0``-P```!(`"P#_`P``2Q\`
M`*H````2``L`TP,``""@```$````$0`4`!@$```DH````````!``%`#O`P``
ME14````````0``L`]@,``&TV``!2````$@`+`#L#``">(0``*P```!(`"P!6
M`P``LAP``-H````2``L`+`0``+LW```F`0``$@`+``L$``#U'P``7`$``!(`
M"P``;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E
M96L`9V5T<&ED`'-T<F-M<`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E
M9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S
M=')C:'(`7U]D97)E9VES=&5R7V9R86UE7VEN9F]?8F%S97,`<F5A9&QI;FL`
M7U]C>&%?9FEN86QI>F4`97AI=`!C;&]S90!?251-7W)E9VES=&5R5$U#;&]N
M951A8FQE`')E860`7U]R96=I<W1E<E]F<F%M95]I;F9O7V)A<V5S`')M9&ER
M`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!?7VQS=&%T
M7W1I;64V-`!P=&AR96%D7V=E='-P96-I9FEC`'-T<FQE;@!G971U:60`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER
M`'-P<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!?7W-T86-K7V-H:U]F86EL`&QI8G!E<FPN<V\`;&EB8RYM=7-L
M+7@X-BYS;RXQ`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!S:&%?:6YI=`!P87)?9&ER;F%M
M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`
M7V5N9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]2
M10````#$GP``"````-"?```(````V)\```@`````H```"`````2@```(````
M"*````@````,H```"````!"@```(````%*````@````@H```"````,B?```&
M`@``S)\```8#``#4GP``!A@``-R?```&'```X)\```8@``#DGP``!B<``.B?
M```&*P``[)\```8P``#PGP``!C0``/2?```&-@``^)\```8X``#\GP``!CP`
M`.B>```'`0``[)X```<$``#PG@``!P4``/2>```'!@``^)X```<'``#\G@``
M!P@```"?```'"0``!)\```<*```(GP``!PP```R?```'#0``$)\```<.```4
MGP``!P\``!B?```'$```')\```<1```@GP``!Q(``"2?```'$P``*)\```<4
M```LGP``!Q4``#"?```'%@``-)\```<7```XGP``!QD``#R?```'&@``0)\`
M``<;``!$GP``!QT``$B?```''@``3)\```<?``!0GP``!R$``%2?```'(@``
M6)\```<D``!<GP``!R4``&"?```')@``9)\```<H``!HGP``!RD``&R?```'
M*@``<)\```<L``!TGP``!RT``'B?```'+@``?)\```<O``"`GP``!S$``(2?
M```',@``B)\```<S``",GP``!S4``)"?```'-P``E)\```<Y``"8GP``!SH`
M`)R?```'.P``H)\```<]``"DGP``!SX``*B?```'/P``K)\```=```"PGP``
M!T$``+2?```'0@``N)\```=#``"\GP``!T0``,"?```'1@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#.@H!P``Z/,H``"#Q`S#````````````````````_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____HP0!``!FD/^C#`$``&:0
M_Z,4`0``9I```````````(U,)`2#Y/#_<?R-00A5B>575HG.4^@-`@``@<,"
MBP``48/L'%"-00104>A1_O__BX,@`0``@\0,4%#_LQP!``#HZ_S__XN#\```
M`(/$$(N[``$``(`X`'4TZ(+]__^)@Y`1``"%P'4*@^P,:@'H'O[__X/L#%#H
M=?[__UK_-^C]_O__@\00QH!W!@```(/L#/\WZ.G^__^`B,H"```"6/\WZ-K^
M__^#Q!"`B,H"```!BP:-2`.#P`2)3>0]____/W8%Z(G]__^#[`S!X`)0Z/W]
M__^+3@2+-H/$$(F#C!$``(L1B1"-D]2C__^)4`2+DT0!``")4`B-D]>C__^)
M4`RZ`0```#G6?@J+/)&)?)`,0NORNA````"%]GX'C12U#````(/L#,<$$```
M``!J`%"-@X%]____=>10_[.0$0``Z$O\__^#Q"")QH7`=1.#[`S_LY`1``#H
M5/W__X/$$(G&@^P,_[.0$0``Z,'\__^-@^.A___HU`(``(/$$(7`=3"#NX@1
M````=1&-@YBA___HN0(``(F#B!$``(N#B!$``(7`=`R#[`Q0Z,44``"#Q!"#
M[`S_LY`1``#HX?W__^B\^O__@\00C67PB?!96UY?78UA_,,Q[8G@@^3P4%#H
M`````($$)&F(``!0Z`````!3Z#$```"!PR:)``"#[!"+1"08:@"-4`3_L_0`
M``#_L_P```!2_S#_L^@```#H'OS__X/$*%O#BQPDPV:09I"0Z(4!``"!PN>(
M``"-BD@!``"-@D@!```YR'0=BX+X````A<!T$U6)Y8/L%%'_T(/$$,G#C70F
M`)##C;0F`````.A%`0``@<*GB```58GE4XV*2`$``(V"2`$``(/L!"G(B</!
MZ!_!^P(!V-'X=!2+DA`!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F`````&:0
M58GE5^CU````@<=3B```5E.#[`R`OV0!````#X5_````BY<,`0``A=)T$X/L
M#/^W)`$``(G[Z.W\__^#Q!"-MRC___^-GRS___^+AV@!```I\\'[`H/K`3G8
M<QJ-="8`@\`!B8=H`0``_Q2&BX=H`0``.=ARZNCU_O__BX<$`0``A<!T%(/L
M#(V'T.#__XG[4.B*_/__@\00QH=D`0```8UE]%M>7UW#C;0F`````)!5Z```
M``!:@<*FAP``B>53Z*+^__^!PY>'``"#[`2+@Q0!``"%P'09C8-L`0``4FH`
M4(V#T.#__U#H0OS__X/$$(M=_,GIMO[__XL4),.+/"3#55=6,?93Z%K^__^!
MPT^'``"#[!R)5"0$A<!T9HG!BX,(`0``,?:)S8L0A=)T5(I%`(3`=`<\/70#
M1>OR*<V)UXLWA?9T/(E4)`Q055&)3"045NAG^?__@\00BTPD"(M4)`R%P'47
M@#PN/741BT0D!"G7C70N`<'_`HDXZP6#QP3KOH/$'(GP6UY?7<.#[!QEBPT4
M````B4PD##')C50D".A;____BTPD#&4K#10```!T!>BL(```@\0<P^@X____
M@<*:A@``5E.)PX/L%&6A%````(E$)`PQP(NR"`$``(U4)`B)V.@6____A<!T
M%XL&BU0D"(T$D(M0!(D0A=)TWX/`!.ORBT0D#&4K!10```!T!>A,(```@\04
M6U[#55>)QU93Z#W]__^!PS*&``"![+P```!EH10```")A"2L````,<"%_P^$
M!@$``(`_``^$_0```(/L#%?H4??__XE$)!2#Q!"%P`^$Y0```(V#3Z'__XE$
M)`B-@TZA__^)1"0,@^P,_W0D$.C2]___@\00A<`/A*,```"-<!-24O]T)!!6
MZ*CW__^#Q!"%P'334%#_="045NB5]___@\00A<!TP(/L#%?H)?K__XDT)(G%
MZ!OZ__^-1`4"B00DZ+_W__]6B<6-@U&A__]74%7HWOG__X/$&(U$)"105>A0
M^?__@\000'09BT0D+"4`\```/0!```!U"8GHZ`+____K#(/L#%7H:/?__X/$
M$(/L#%7H3/G__X/$$.E&____@^P,_W0D$.B8]___B3PDZ/#X__^#Q!"+A"2L
M````92L%%````'0%Z/T>``"!Q+P```!;7E]=PU:)QE/HZ_O__X'#X(0``('L
MK````&6A%````(F$)*0````QP(U$)!105NCN^/__@\00A<!U,8M4)!R!X@#P
M``"!^@!```!T"('Z`*```'494%!J`E;H(_;__X/$$(7`#Y3`#[;`ZP(QP(N,
M))P```!E*PT4````=`7H=!X``('$I````%M>PU57B<=6B=93Z&#[__^!PU6$
M``"#["QEH10```")1"0<,<"`.CUU`4:#[`Q6Z,7X__^#Q!")1"0(C50D&(GX
MZ,7\__^)Q87`="F#[`Q0Z*3X__^#Q!`Y1"0(#X>_````,<"*%`:(5`4`0(32
M=?3I'`$``(N#"`$``,=$)`0`````BPB+1"0$@SR!`'0&_T0D!.OP@[N$$0``
M`(TLA0@```!T'5)255'H*_7__XN3"`$``(/$$(D"A<!U3.G/````B4PD#(/L
M#%7'@X01```!````Z-#U__^#Q!")PH7`#X2K````4(U%^%"+3"0445*)5"0<
MZ+_U__^+5"0<BX,(`0``@\00B1"+@P@!``"+`,=$*/P`````BT0D!(E$)!B)
M^(H0A-)T"(#Z/70#0.ORBZL(`0``BTPD&(/L#"GXBU4`C12*B50D$(M,)!2-
M1`$"4.A1]?__BU0D%(/$$(D"A<!T+(M%`(M4)!B+!)"*%T>)P4"(4/^$TG0%
M@/H]=>[&`3TQTHH,%H@,$$*$R77UBT0D'&4K!10```!T!>C+'```@\0L6UY?
M7<-3Z+_Y__^!P[2"``"#[!2+@P`!``#_,.@"]___C9.`W___4HV35Z'___^S
M&`$``%)0Z,CV__^#Q"A;PU93Z(/Y__^!PWB"``"#[!"+LP`!``#_-NC&]O__
MB00DZ*#___]8_S;HMO;__UE>:@")PHV#TZ/__U!0C8--B?__4(V#<Z'__U!2
MZ.3S__^#Q"1;7L-55U93Z"SY__^!PR&"``"![!P@``!EH10```")A"0,(```
M,<#HY?/__X/L#(V3B*'__U)0C8.,H?__4&@!$```C6PD)E7HA//__X/$((U0
M`8'Z`1```'8"#PM`=00QP.M94&@`$```C;0D$Q```%95Z/GT__^#Q!")Q87`
M>-^#[`R-0`%0Z.3S__^#Q!"%P'3,.?!S!XT4*#G6<KPY\'8'C10N.=!RL8']
M`1```'^I_(G'B>GSI,8$*`"+C"0,(```92L-%````'0%Z&0;``"!Q!P@``!;
M7E]=P^DA____55=64^A-^/__@<-"@0``@>R\$```9:$4````B80DK!```#'`
MB[0DT!```(N\)-00``"-@YBA___H0/K__XD$)%55:B]6Z.7S__^#Q!"%P'02
MB?*-@Z&A___HB_S__^D@`0``@^P,C:NNH?__5NAM]?__6EF)1"0,55?H(/7_
M_X/$$(G'C8-/H?__B40D"(V#L*'__XE$)`R%_W2U@#\`=02+?"0(@SPD`'07
M4%!7_W0D#.B(\O__@\00A<`/A*T```"#[`Q7Z!3U__^#Q!"`?`?_+W4'2,8$
M!P#K\HM,)`2-1`@!/?\/```/CV+___]04(V#@:+__U;_="085U!H`!```(V\
M),@```!7Z-_Q__^#Q"!`/0`0``!V`@\+45&-1"0D4%?H%?3__X/$$(7`=3Z+
M1"0L)0#P```]`(```'4N4E)J`5?HE/'__X/$$(7`=1V)^HV#H:'__^B*^___
M@^P,5^AW\O__@\00B<;K%%!056H`Z";T__^#Q!")Q^D5____BX0DK!```&4K
M!10```!T!>B\&0``@<2\$```B?!;7E]=PXM4)`2)T(H*A,ET"$*`^2]U].OP
MPU934XMT)!#HD/;__X'#A7\``(7V=#B`/@!T,X/L#%;H`?3__X/$$(U$!O\Y
MQG,6@#@O=0U(Z_2`."^-4/]T,XG0.<9R\CG&=2F`/B]U"X/L#(V#3Z'__^L)
M@^P,C8.PH?__4.B]\?__@\00ZSF`."]U!4@YQG+V*?"-4`*!^@`0``!W($`]
M`!```'8"#PM14%:-LX0!``!6Z$CR__^#Q!")\.L",<!:6U[#5[DB````5E/H
MY?7__X'#VGX``(/L,&6A%````(E$)"PQP(U\)`J-LUS?___\\Z2-@[*A___H
M#OC__XV#NZ'__^@#^/__C8/#H?__Z/CW__^-@\RA___H[??__XV#TZ'__^CB
M]___C8/CH?__Z-?W__^-@YBA___HS/?__XV#[Z'__^C!]___C8/YH?__Z+;W
M__^-@P.B___HJ_?__XV#H:'__^B@]___C8,-HO__Z&;W__^%P'0-B<*-@_FA
M___HP?G__XV#'J+__^A*]___B<*%P'0+C8,IH?__Z*7Y__^-@S"B___H+O?_
M_XG"C8.8H?__A=)U-HV#0*+__^@7]___B<*%P'4?4(V#4:+__VH*4(U$)"=0
MZ"_P__^#Q!"%P'4/C50D)8V#[Z'__^A3^?__C8/3H?__C9-<HO__Z$+Y__^+
M1"0L92L%%````'0%Z)L7``"#Q#!;7E_#4^B0]/__@<.%?0``@^P(@[M``0``
M_W4JC8/OH?__Z)KV__^)PC'`A=)T$8H2@/HP#Y7!,<"$T@^5P"'(B8-``0``
MBX-``0``@\0(6\-3Z$/T__^!PSA]``"#[`CHWO'__X/L#%#H)?#__X/$$(7`
M=`*+`(/$"%O#55=64^@5]/__@<,*?0``@^P<BWPD,(V#7J+__^@D]O__A<!T
M!X`X`(G&=0V)^HV#7J+__X/$'.M:4%!75NB%[___@\00A<!U4X/L#%?H5?'_
M_XDT)(G%Z$OQ__^-1`4"B00DZ._N__^)-"2)PHV#KJ'__U"-@X&B__]74%*)
M5"0LZ`'Q__^+5"0LC8->HO__@\0\6UY?7>D5^/__@\0<6UY?7<-5N08```!7
M5E/H;//__X'#87P``('L+($``(N$)$"!``"-O"3$````B40D"(VS*`$``&6A
M%````(F$)!R!```QP(V#)*'__\>$)+0`````````B80DK````(V#3Z'__XF$
M)+````#\\Z6-@T"A___'A"3``````````(F$)+@```"-@T6A__^)A"2\````
MC8.8H?__Z`CU__^%P'0A@#@`B<9T&H/L#%#HK_[__XDT).A.[O__B40D$.G8
M!```Z&[^__^-O"2X````B<:%P'4SBP>%P'0GZ,;T__^%P'4%@\<$Z^R`.`!T
M]H/L#%#H$>[__X/$$(G&A<!TY.L&C;-NHO__@^P,5NCW[___C40``8D$).B;
M[?__@\00C9-UHO__B<>)Q0^V!H3`=!E11E!2B50D#%6#Q0+HIN___X/$$(L4
M).O@C;0DQ````(LNA>UT*8GHZ$CT__^)Q87`="6`.`!T(.@=]O__A<!T%X/L
M#%7HC>W__X/$$(G%C;0DK````.LR@\8$Z\.+%H72="N`.@!T)HG0B10DZ.CU
M__^+%"2%P'0.@^P,4NA5[?__@\00B<6#Q@2%[73/@^P,5>A`[___B3PDB<;H
M-N___XVT!@0$``")-"3HU^S__XE$)!18C8-ZHO__6E=0C8.PH?__B40D'%"-
M@W^B__]54/]T)"#HW>[__X/$&&C``0``_W0D$.AL[O__@\000'4SZ%'N__^+
M`(/X$70G@^P,4/]T)!2+1"0<_S"-@XBB__]0BX/L````_S#HJ.W__X/$(.LZ
M556-1"0D4/]T)!#H0^[__X/$$(G%A<!T+?]T)`2+1"0,_S"-@\.B__]0BX/L
M````_S#H;.W__X/$$,<$)`````#I`P,``(M$)"PE`/```#T`0```=<.+?"0T
MZ'3N__\YQW6VBT0D+"7_`0``/<`!``!UIH/L#%;HY^O__XE$)!"-@VFB___H
MQO+__X/$$(7`=0B+1"0(BS#K((/L#%#H$.S__UY?4(M$)!3_,.@C^/__@\00
MB<:%P'38@^P,5NCP[?__@\00B<>#^`-V7HV#%J/__U%14(U$/OQ0Z#/K__^#
MQ!"%P'5$@_\$=`>`?#[[+W4XBT0D"(MX!(7_="V#[`Q7Z*SM__^#Q!"#^`-V
M'(U$!_Q24HV3&Z/__U)0Z/'J__^#Q!"%P'4"B?[H9/O__XG'A<`/A64!``!0
M4&H`5NA_Z___@\00B<:%P`^$3@$``&H":O]J[E#HENK__X/$#&H&C:PD)`$`
M`%56Z'/L__^#Q!"`O"0<`0```'5=@+PD'0$``$-U4X"\)!X!``!!=4F`O"0?
M`0``0W4_@+PD(`$``$AU-8"\)"$!``!%=2MJ`FK_:L96Z#CJ__^#Q`QJ*556
MZ!SL__^-@].C__]>7U!5_W0D'.FI````:@!J`&H`5N@-ZO__Z,4/``")Q8/$
M$%%H`(```(V4)"0!``!2B50D%%;HV^O__X/$$(M4)`B%P'X+45!25>CF#P``
MZ\^#[`Q6Z)SK__]86E6-M"3K````5NC'$```@\00C9-UHO__50^V!#Y0C00_
M1U*-K"3_````B50D%`'H4.@U[/__@\00@_\4BU0D"'76C8/3H___QH0D&P$`
M``!75U"-@["A__]54(V#(*/___]T)!A0_W0D'.C\Z___@\0@Z8(```"-DURB
M__^-@^^A___H#?/__XV[/:/__^A(Z?__5E:-L].C__]64(V#+Z/___]T)!S_
M="084/]T)!SHMNO__X/$(%)2:,`!``#_="0,Z$/K__^#Q!!`=2OH*.O__X,X
M$74AZ/[H__]%45954/]T)!S_="085_]T)!SH=^O__X/$(.N_@^P,_W0D$.@6
MZ___BU0D$(V#F*'__^B!\O__6/]T)`SHQOG__X/$$(N$)!R!``!E*P44````
M=`7HRA```(L$)('$+($``%M>7UW#55=64^BU[?__@<.J=@``@^P8B[,``0``
M_S;H^.K__UG_-HG'Z.[J__^*5V2(4&6-@].A___HJ^___X/$$(7`=`N`.#%U
M!H!X`0!T!>A[]___@^P,_S;HO.K__XV33J/__VH#:@%24.@;Z?__@\0@B<>%
MP'1$BT`,@^P,BRC_-NB3ZO__@\0,C9-0H___4E50Z!+I__^+1PR#Q!"+./9'
M"D!T%H/L#/\VZ&KJ__]=6E=0Z"'H__^#Q!"#[`S_-NA4ZO__C9-5H___:@-J
M`5)0Z+/H__^#Q"")Q87`=&>-@Z&A___H_>[__XG'A<!T!8M%#.LWZ)'S__^%
MP(G'BT4,="&#[`R+*/\VZ`KJ__^#Q`Q755#HC^C__XD\).BWZ?__ZQ^+DXP1
M``"+.HLH@^P,_S;HX>G__X/$#%=54.AFZ/__@\00@^P,_S;HR>G__X/$#(V3
M5Z/__VH!4E#HU^;__UK_-HG'Z*WI__^#Q`R-DVRC__]25U#H+.C__UG_-NB4
MZ?__QD!E`(V#F*'__^A3[O__@\00B8.($0``A<!U)H/L#/^SC!$``.B7^/__
M@\00B8.($0``A<!U"X/L#(V#<J/__^LW4%!HP`$``/^SB!$``.CPZ/__@\00
MC5`!@_H!=B"#^!%T&U"+@XP1``#_LX@1``#_,(V#DZ/__U#H=>;__X/$#%M>
M7UW#5U93BW0D$.BHZ___@<.==```@^P,5NC]]/__B00DZ.#T__^#Q!")Q^CQ
M]O__A<!T*87V="6`/@!T(%!0C8-ZHO__4%?H%.?__X/$$#G'=0I;B?!>7^D2
M[O__6UY?PU4QTE=64X'L?`$``(E$)`AEH10```")A"1L`0``,<"+1"0(BTR0
M'(U$)"P/R8D,D$*#^A!UZ8V,)"P!``"+4#0S4""#P`0S4`0S4/S1PHE0/#G(
M=>B+1"0(BP")1"00BT0D"(M4)!"+0`3!R@*)1"08BT0D"(M,)!B+0`C!R0*)
M1"0,BT0D"(M\)`R+;"0,BT`,,<\C?"00,WPD#(E$)!2+1"0(BT`0B40D'(M$
M)"R+7"0<C;0#F7F"6HM$)!"+7"04P<`%`?"+="0,,W0D%"-T)!@S="04`<:+
M1"0PC80#F7F"6HG+`<>)\#'3P<`%(?/!S@(!QXM$)#0QRXV$!9EY@EJ+;"0X
M`<.)^,'`!8V,*9EY@EJ+;"0\`<.)T#'P(?C!SP(QT(V4*IEY@EJ+;"1``<B)
MV<'!!0'(B?$Q^2'9,?&-M"Z9>8):BVPD1`'1B<+!P@7!RP(!T8GZ,=HAPL'(
M`C'ZC;POF7F"6HML)$@!\HG.P<8%`?*)QHG8,?`AR#'8C9PKF7F"6HML)$P!
M^(G7P<<%`?B)SXGQP<\",?DAT3'QC;0NF7F"6HML)%`!V8G#P<,%`=F)TXGZ
MP<L",=HAPL'(`C'ZC;POF7F"6HML)%0!\HG.P<8%`?*)QHG8,?`AR#'8C9PK
MF7F"6HML)%@!^(G7P<<%`?B)SXGQP<\",?DAT3'QC;0NF7F"6HML)%P!V8G#
MP<,%`=F)TXGZP<L",=HAPL'(`C'ZC;POF7F"6HML)&`!\HG.P<8%`?*)QHG8
M,?`AR#'8C9PKF7F"6HML)&0!^(G7P<<%`?B)SXGQP<\",?DAT3'QC;0NF7F"
M6@'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J)Q8G8`?*)SC'HP<8%(<C!R0(!
M\HMT)&@QV(VT-YEY@EJ)[P'PB=8QS\'&!2'7P<H"`?"+="1L,>^-G#.9>8):
MB<X!WXG#,=;!PP4AQL'(`@'?BUPD<#'.C9P=F7F"6HML)'0!WHG[P<,%C8PI
MF7F"6HML)'@!WHG3,<,A^S'3P<\"C90JF7F"6@'+B?'!P04!RXG!,?DA\<'.
M`C'!`=&)VL'"!0'1BU0D?(V$$*'KV6Z)^C'R,=K!RP(!PHG(P<`%`<*+A"2`
M````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDA````,'/`HVT#J'KV6Z)
MV3'Y,=$!\8G&P<8%`?&)UHN4)(@```#!S@*-G!.AZ]ENB?HQ\C'"`=J)R\'(
M`L'#!0':B<.+A"2,````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDD```
M`,'/`HVT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4))0```#!S@*-G!.AZ]EN
MB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"28````C;P'H>O9;HGP,=@QR`'XB=?!
MQP4!^(G/BXPDG````,'/`HVT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4)*``
M``#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+A"2D````C;P'H>O9
M;HGP,=@QR`'XB=?!QP4!^(G/BXPDJ````,'/`HVT#J'KV6Z)V3'Y,=$!\8G&
MP<8%`?&)UHN4)*P```#!S@*-G!.AZ]ENB?HQ\C'"P<@"`=J)R\'#!0':B<.+
MA"2P````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPDM````,'/`HVT#J'K
MV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4)+@```#!S@*-G!.AZ]ENB?HQ\C'"P<@"
M`=J)R\'#!0':B<.+A"2\````C;P'H>O9;HGP,=@QR`'XB=?!QP4!^(G/BXPD
MP````,'/`HVT#J'KV6Z)V3'Y,=$!\8G&P<8%`?&)UHN4),0```#!S@*-G!.A
MZ]ENB?HQ\C'"P<@"B<4!VHN$),@```")R\'#!0':C9P'H>O9;HGP,>@QR`'8
MB=/!R0+!PP4!V(GK"<N)WXGK(=<AR\'*`@G[B[PDS````(VT/MR\&X^)SP'S
MB<8)U\'&!0'SB?Z)SR'&(=?!R`()]XNT)-````"-M#7<O!N/`?>)WL'&!0'W
MB=8)QB'>P<L"B?6)UB'&">Z+K"34````C8PIW+P;CXG=B<,!S@GKB?DA^\'!
M!0'.B=F)PR'K"<N+C"38````C90*W+P;CXGI`=/!SP*)\@GYP<(%(?$!T\'.
M`HG*B>DA^0G1BY0DW````(V$$-R\&X^)^@'!B=@)\L'`!0'!B=")^B'8(?+!
MRP()PHN$).````"-A`7<O!N/`<*)R,'`!0'"B?`)V"'(B<6)\"'8">B+K"3D
M````C;POW+P;CP'XB=?!QP4!^(G/B=G!SP()^2'1B<V)V2'Y">F+K"3H````
MC;0NW+P;CP'QB<;!Q@4!\8G6B?K!S@()\B'"P<@"B=6)^B'R">J+K"3L````
MC9PKW+P;CP':B<O!PP4!VHG#B?`)V"'(B<6)\"'8">B+K"3P````C;POW+P;
MCP'XB=?!QP4!^(G/B=G!SP()^2'1B<V)V2'Y">F+K"3T````C;0NW+P;CP'Q
MB<;!Q@4!\8G6B?K!S@()\B'"B=6)^B'R">J+K"3X````C9PKW+P;CP':B<O!
MR`+!PP4!VHG#B?`)V"'(B<6)\"'8">B+K"3\````C;POW+P;CP'XB=?!QP4!
M^(G/B=G!SP()^2'1B<V)V2'Y">F+K"0``0``C;0NW+P;CP'QB<;!Q@4!\8G6
MB?K!S@()\B'"P<@"B=6)^B'R">J+K"0$`0``C9PKW+P;CXG%B?`!V@GHB<LA
MR,'#!0':B<.)\"'H"=B+G"0(`0``C9P?W+P;CP'8B=/!R0+!PP4!V(GK"<N)
MWXGK(=<AR\'*`@G[B[PD#`$``(VT/MR\&X\!\XG&P<8%`?.)S@G6B?>)SB''
M(=;!R`()_HN\)!`!``"-O#W<O!N/`?Z)W\''!0'^B=<)QR'?P<L"B?V)UR''
M">^+K"04`0``C8PIW+P;CP'YB??!QP4!^8G'"=\A]XG]B<<AWPGOBZPD&`$`
M`(V4*MR\&X\!UXG*P<X"P<(%`=>+E"0<`0``C900UL%BRHG8,?`QR,')`@'0
MB?K!P@4!T(N4)"`!``"-G!/6P6+*B?(QRC'ZP<\"`=J)P\'#!0':BYPD)`$`
M`(VT'M;!8LJ)RS'[,</!R`(!\XG6P<8%`?.)QHN$)"@!``"-C`'6P6+*B?@Q
M\#'0`<B)V<'!!0'(B=&+E"0L`0``P<D"C907UL%BRHGW,<\QWP'7B<+!P@4!
MUXN4)#`!``#!RP*-M!;6P6+*B<HQVC'"P<@"`?*)_L'&!0'RB<:+A"0T`0``
MC80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!P8N$)#@!``"-G`/6P6+*B?`Q^#'0
M`=B)R\'#!0'8B=.+E"0\`0``BVPD$,'+`HV4%M;!8LJ)_C'>,<[!R0(!UHG"
MP<(%`=:+E"1``0``C;P7UL%BRHG:,<HQPL'(`@'ZB??!QP4!^HG'BX0D1`$`
M`(V$`];!8LJ)RS'[,?/!S@(!PXG0P<`%`<.+A"1(`0``C8P!UL%BRHGX,?`Q
MT`'(B=G!P04!R(G1BY0D3`$``,')`HV4%];!8LJ)]S'/,=_!RP(!UXG"P<(%
M`=>+E"10`0``C;06UL%BRHG*,=HQPL'(`@'RB?[!Q@4!\HG&BX0D5`$``(V$
M`=;!8LJ)V3'Q,?G!SP(!P8G0P<`%`<&+A"18`0``C9P#UL%BRHGP,?@QT`'8
MB<O!PP4!V(G3BY0D7`$``,'+`HV4%M;!8LJ)_C'>,<[!R0(!UHG"P<(%`=:+
ME"1@`0``C;P7UL%BRHG:,<HQPL'(`@'ZB??!QP4!^HN\)&0!``"-O#O6P6+*
MB<LQPS'SP<X"`?N)U\''!0'[B[PD:`$``(V\/=;!8LH!SXG!,?$#="04,='!
MR@(#5"0,`?F)WP-<)!C!QP4!^8M\)`@#1"0<B0^)7P2)5PB)=PR)1Q"+A"1L
M`0``92L%%````'0%Z(,"``"!Q'P!``!;7E]=PU/H=-___X'#:6@``(/L%&I@
MZ)W:___'``$C16?'0`2)J\WOQT`(_MRZF,=`#'94,A#'0!#PX=+#QT`4````
M`,=`&`````#'0%P`````@\086\-55U93@^P<BVPD.(M<)#"+="0TC03M````
M``-#%',#_T,8B4,4BWM<B>C!Z!T!0QB-0QR)1"0(A?]T5;E`````B>@I^3G-
M?@*)R(M4)`@!^CGR<PJ-#`(YSG,#_`\+C3P&B7PD##GR=@0Y^G+N_(G7B<$I
MQ?.DBTM<`<&)2UR#^4!U<8G8Z$CS__^+="0,ZP'\@_T_?C`[="0(=@>-0UPY
MQG*YC49`B40D##ET)`AV!CE$)`ARIHM\)`BY$````(/M0/.EZ[T[="0(=@J+
M1"0(`>@YQG*&.W0D"',-C00N.40D"`^"<____XM\)`B)Z?.DB6M<@\0<6UY?
M7</H(0$```4<9P``55=64X/L'(M<)#2+="0PB40D!(M#%(M3&(G%P>@##\J)
M5"0(@^`_C5,<#\V->`&)%"3&1`,<@`'Z@_\X?BFY0````"GY_#'`B=?SJHG8
MB4PD#.AU\O__BSPDBT0D#+D.````\ZOK#KDX````*?G\,<")U_.JBT0D"(EK
M6(E#5(G8Z$;R__^+`X/L#,'H&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#!XA&
M!`^W0P:(1@6+0P2(9@:+0P2(1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#"(A&
M"P^V0P^(1@P/MT,.B$8-BT,,B&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+0Q"(
M9A*+0Q"(1A-3BUPD%.@GVO__@\0L6UY?7<.+!"3#4^C\W/__@</Q90``@^P(
MZ(?:__^#Q`A;PV:0Z'7>__^!PM=E``"+@B#___^#^/]T*E6)Y5.-FB#___^#
M[`2-="8`D/_0BT/\@^L$@_C_=?.+7?S)PXVV`````,.#[`SH-]W__X/$#,,`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"]T;7``4$%27U1-4$1)4@!414U01$E2`%1-4`!54T52`%5315).04U%
M`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!2
M3T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)5
M1P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)
M3TX`,2XP-3(`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&
M2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2![
M"B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C
M:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@
M96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H
M:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L
M(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R
M971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H
M*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I
M('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S
M92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A
M<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*
M;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M
M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D
M:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I
M+F,````!&P,[\````!T```"XD?__#`$``#B5__\P`0``6)7__]P+```:F?__
M1`$``*:9__^0`0``U9G__Z@!```WFO__U`$``(N;__^<`@``$IS__^@"``"Z
MG?__:`,``/6=__^8`P``2I[__^0#```DG___8`0``"F?__]T!```SJ#__VP%
M``#CH/__@`4``(VA___0!0``Z:+__Q0&```VH___-`8``&&C__]@!@``!:3_
M_^`&``#!J?__:`H``,NK__^("P``*:S__R0,```%N/__9`P``%>X__^(#```
M4[G__\0,``!YNO__"`T``'VZ__\<#0``%``````````!>E(``7P(`1L,!`2(
M`0``(````!P```"DD/__@`,````."$8.#$H/"W0$>``_&CLJ,B0B$````$``
M````E/__&`````````!(````5````,Z7__^,`````$$."(4"00X,AP-!#A"&
M!$,.%(,%3@XP=PXT00XX00X\10Y`2`XP:PX40\,.$$'&#@Q!QPX(0<4.!```
M%````*`````.F/__+P````!##B!K#@0`*````+@````EF/__8@````!,#@B&
M`D$.#(,#10X@`DT.#$'##@A!Q@X$``#$````Y````%N8__]4`0```$$."(4"
M00X,AP-##A"&!$$.%(,%40[0`6,.W`%!#N`!3`[0`5\.W`%$#N`!2`[0`4P.
MU`%!#M@!1`[<`4$.X`%(#M`!10[4`4$.V`%$#MP!00[@`4@.T`%'#MP!00[@
M`5P.Y`%)#N@!00[L`4$.\`%(#M@!10[<`4$.X`%(#M`!7P[<`4$.X`%(#M`!
M0P[<`4$.X`%(#M`!2`[<`40.X`%0#M`!6PX40<,.$$'&#@Q!QPX(0<4.!$@`
M``"L`0``YYC__X<`````00X(A@)##@R#`U$.N`%4#KP!00[``4@.L`%?#K0!
M00ZX`4(.O`%!#L`!2`ZP`6<.#$'##@A!Q@X$``!\````^`$``"*9__^H`0``
M`$$."(4"00X,AP-##A"&!$,.%(,%3@Y`50Y,00Y02`Y`6`Y,00Y02`Y``DX.
M1$$.2$$.3$$.4$X.0%(.3$$.4%(.0$L.1$0.2$4.3$$.4%8.0'<.3%4.4$P.
M0`)'#A1!PPX00<8.#$''#@A!Q0X$`"P```!X`@``2IK__SL`````00X(@P).
M#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"H`@``59K__U4`````00X(
MA@)!#@R#`TX.'$@.($X.'$(.($8.'$$.&$(.'$D.($$.)$<.*$<.+$$.,$@.
M#$'##@A!Q@X$``!X````]`(``%Z:___:`````$$."(4"00X,AP-!#A"&!$$.
M%(,%40ZP0%<.O$!'#L!`00[$0$<.R$!%#LQ`10[00$@.L$!5#K1`10ZX0$@.
MO$!!#L!`2`ZP0$D.O$!$#L!`2`ZP0`)(#A1!PPX00<8.#$''#@A!Q0X$````
M$````'`#``"\FO__!0````````#T````A`,``*V:__^E`0```$$."(4"00X,
MAP-!#A"&!$$.%(,%40[0(6P.U"%!#M@A0@[<(4$.X"%(#M`A60[<(4<.X"%&
M#MPA00[8(44.W"%!#N`A2`[0(6H.U"%!#M@A00[<(40.X"%(#M`A2P[<(4$.
MX"%(#M`A8@[4(4$.V"%'#MPA1`[@(4$.Y"%!#N@A10[L(4@.\"%(#M`A2P[4
M(4$.V"%%#MPA00[@(4@.T"%5#M0A00[8(4(.W"%!#N`A2`[0(50.W"%!#N`A
M2`[0(44.U"%!#M@A00[<(4(.X"%(#M`A8@X40\,.$$'&#@Q!QPX(0<4.!!``
M``!\!```6IO__Q4`````````3````)`$``!;F___J@````!!#@B&`D$.#(,#
M00X06PX<00X@2`X0:@H.'$@+0PX<1PX@2`X09`X400X800X<1PX@2`X01PX,
M0<,."$'&#@1`````X`0``+6;__]<`0```$$."(<"1@X,A@-!#A"#!$X.0`+S
M#D1(#DA!#DQ%#E!(#D!Y#A!!PPX,0<8."$''#@0``!P````D!0``S9S__TT`
M````00X(@P).#A!\#@A!PPX$*````$0%``#ZG/__*P````!!#@B#`DX.$$@.
M'$$.($@.$$D."$'##@0```!\````<`4``/F<__^D`````$$."(4"00X,AP-!
M#A"&!$$.%(,%3@XP90H.%$(+00XT00XX00X\00Y`2`XP1PX\00Y`9PY$1PY(
M00Y,00Y05@X40<,.$$'&#@Q!QPX(0<4.!$4.,(,%A0*&!(<#0PX40<,.$$'&
M#@Q!QPX(0<4.!(0#``#P!0``'9W__[P%````00X(A0)&#@R'`T$.$(8$00X4
M@P51#L""`@*-"@[,@@)!#M""`E8+;@[,@@)!#M""`D@.P(("40[,@@)!#M""
M`E0.P(("4@[$@@)"#LB"`D$.S(("10[0@@)+#L""`G`.S(("00[0@@)(#L""
M`F\.S(("00[0@@)(#L""`DP.S(("00[0@@)C#LR"`D<.R(("00[,@@)!#M""
M`DL.U(("1P[8@@)!#MR"`D0.X(("2`[(@@)%#LR"`D0.T(("2`[`@@)2#LR"
M`D$.T(("1`[4@@)&#MB"`D<.W(("2`[@@@)(#L""`D,.Q(("00[(@@)%#LR"
M`D0.T(("2`[`@@)*#L2"`D8.R(("1P[,@@)(#M""`D@.P(("?`[,@@)!#M""
M`E<.P(("3P[,@@)!#M""`D8.S(("00[(@@)!#LR"`D8.T(("2`[`@@))#LR"
M`D$.T(("2`[`@@).#L2"`D$.R(("00[,@@)%#M""`D@.P(("7@[,@@)!#M""
M`D@.P(("2@[$@@)!#LB"`D<.S(("00[0@@)(#L""`E8*#L2"`D$.R(("0@[,
M@@)!#M""`D@.P(("3`[$@@)"#LB"`D(.S(("00[0@@)(#L2"`D(.R(("2`[,
M@@)!#M""`D@.P(("?@[$@@)"#LB"`D(.S(("00[0@@)(#L2"`D(.R(("00[,
M@@)!#M""`DP.S(("00[(@@)!#LR"`D$.T(("1`[4@@)%"T(.Q(("0@[(@@)"
M#LR"`D$.T(("3P[`@@)!#L2"`D4.R(("2`[,@@)%#M""`D@.P(("20[$@@)!
M#LB"`D$.S(("00[0@@)'#L""`D,.S(("00[0@@)&#LR"`D$.R(("00[,@@)(
M#M""`D@.P(("1P[$@@)%#LB"`D4.S(("3@[0@@)(#L""`E@.Q(("00[(@@)!
M#LR"`D<.T(("00[4@@)*#MB"`D$.W(("1`[@@@)(#L""`F(.Q(("00[(@@)'
M#LR"`D$.T(("2@[4@@)$#MB"`D$.W(("1`[@@@)(#L""`D$.Q(("00[(@@)%
M#LR"`D0.T(("2`[`@@)4#L2"`D$.R(("00[,@@)!#M""`D0.U(("1`[8@@)!
M#MR"`D0.X(("2`[`@@)%#LR"`D0.T(("50[,@@)$#M""`D@.P(("7@X40<,.
M$$'&#@Q!QPX(0<4.!``<`0``>`D``%&?__\*`@```$$."(4"00X,AP-!#A"&
M!$$.%(,%3@XL2`XP1@XL0@XP6PX@5PXL0@XP30XT0@XX00X\00Y`2`X@3`XL
M1`XP2`XD1PXH00XL00XP2PX@2PXL0@XP1@XL00XH00XL00XP2`X@0PXL0@XP
M30XT0@XX00X\00Y`2`X@;0H.+$0.,$@.)$$.*$$.+$$.,$\+30XL0@XP2`XD
M00XH00XL00XP2`X@0PH.+$(.,$@.)$@.*$$.+$$.,$8.+$(.,$H.)$<.*$$.
M+$$.,$8.+$(.,%<.($T.+$8.,$@.($T.+$@+00XD00XH10XL1@XP2`X@3@XD
M3`XH0@XL1PXP10X@0PX40<,.$$'&#@Q!QPX(0<4.!`!0````F`H``#N@__]>
M`````$$."(<"00X,A@-!#A"#!%(.'$$.(%`.$%4.%$$.&$<.'$$.($@.$$4*
MPPX,0\8."$''#@1%"T'##@Q!Q@X(0<<.!`!$````[`H``'2)___5`0```$0,
M`0!,$`4"=0!"$`<"=7P0!@)U>$,0`P)U=$P/`W5P!@.L`<$,`0!!PT'&0<=!
MQ4,,!`0````\````-`L``/V?___<"P```$$."(4"0PX,AP-!#A"&!$$.%(,%
M1@Z0`P/+"PX40<,.$$'&#@Q!QPX(0<4.!```(````'0+``"9J___4@````!!
M#@B#`DX.'$(.('\."$'##@0`.````)@+``#'J____`````!!#@B%`D$.#(<#
M00X0A@1!#A2#!4,.,`+P#A1!PPX00<8.#$''#@A!Q0X$0````-0+``"'K/__
M)@$```!+#@B%`D$.#(<#00X0A@1!#A2#!4,.,`*$#CP"@`Y`3`X40<,.$$'&
M#@Q!QPX(0<4.!``0````&`P``&FM__\$`````````!P````L#```6:W__QD`
M````00X(@P).#A!(#@A!PPX$````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_____P````#_____
M``````$````4`P```0```!\#```/````1P0```P`````$```#0```$$Y``#U
M_O]O]`$```4```#,"```!@```,P"```*````900```L````0````%0``````
M```#````W)X```(```"X`0``%````!$````7````Y`T``!$````T#0``$@``
M`+`````3````"````!@`````````^___;P$```CZ__]O"@``````````````
M```````````````````````````````````````````,G@`````````````V
M$```1A```%80``!F$```=A```(80``"6$```IA```+80``#&$```UA```.80
M``#V$```!A$``!81```F$0``-A$``$81``!6$0``9A$``'81``"&$0``EA$`
M`*81``"V$0``QA$``-81``#F$0``]A$```82```6$@``)A(``#82``!&$@``
M5A(``&82``!V$@``AA(``)82``"F$@``MA(``,82``#6$@``YA(``/82```&
M$P``%A,``"83```V$P``1A,``%83``!F$P``=A,``(83``"6$P``P!,`````
M````````03D`````````$```````````````````````````````````````
M`````````````*````5````%00``$$```!=!```80````````/____^V0@``
M1T-#.B`H06QP:6YE(#$P+C,N,5]G:70R,#(Q,#DR,2D@,3`N,RXQ(#(P,C$P
M.3(Q```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI
M=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`
M+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````````"P````$````"````M`$``+0!```7```````````````!````````
M`!,````'`````@```,P!``#,`0``*```````````````!``````````F````
M]O__;P(```#T`0``]`$``-@````$``````````0````$````,`````L````"
M````S`(``,P"````!@``!0````$````$````$````#@````#`````@```,P(
M``#,"```900``````````````0````````!`````"0````(````T#0``-`T`
M`+`````$``````````0````(````20````D```!"````Y`T``.0-``"X`0``
M!````!,````$````"````%(````!````!@`````0````$```$0``````````
M`````0````````!-`````0````8````@$```(!```(`#`````````````!``
M```$````6`````$````&````H!,``*`3```8```````````````(````"```
M`&$````!````!@```,`3``#`$P``@24`````````````$`````````!G````
M`0````8```!!.0``03D```P```````````````$`````````;0````$````"
M`````$````!```!F/@`````````````$`````````'4````!`````@```&A^
M``!H?@``]```````````````!`````````"#`````0````(```!<?P``7'\`
M`$P,``````````````0`````````C0````$````#````_)T``/R-```(````
M```````````$`````````)0````!`````P````2>```$C@``"```````````
M````!`````````";````!@````,````,G@``#(X``-`````%``````````0`
M```(````7`````$````#````W)X``-R.```D`0`````````````$````!```
M`*0````!`````P````"@````D```)```````````````!`````````"J````
M"`````,```!`H```))```#`0`````````````"``````````KP````$````P
M`````````"20```Q```````````````!`````0````$````#````````````
:``!5D```N````````````````0``````````
